#
# spec file for package sdbootutil
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define nvr %{name}-%{version}-%{release}
%if 0%{?_build_in_place}
%define git_version %(git log '-n1' '--date=format:%Y%m%d' '--no-show-signature' "--pretty=format:+git%cd.%h")
BuildRequires:  git-core
%else
# this is required for obs' source validator. It's
# 20-files-present-and-referenced ignores all conditionals. So the
# definition of git_version actually happens always.
%define git_version %{nil}
%endif
Name:           sdbootutil
Version:        1+git20240122.c0d8f76%{git_version}
Release:        1.2
Summary:        script to install shim with sd-boot
License:        MIT
URL:            https://en.opensuse.org/openSUSE:Usr_merge
Source:         %{name}-%{version}.tar
Requires:       efibootmgr
Requires:       jq
Requires:       pcr-oracle
Requires:       sed
Requires:       systemd-boot
Supplements:    (systemd-boot and shim)
Requires:       (%{name}-snapper if (snapper and btrfsprogs))
ExclusiveArch:  aarch64 ppc64le riscv64 x86_64

%description
Hook scripts to install shim along with systemd-boot

%package snapper
Summary:        plugin script for snapper
Requires:       %{name} = %{version}
Requires:       btrfsprogs
Requires:       sdbootutil >= %{version}-%{release}
Requires:       snapper

%description snapper
Plugin scripts for snapper to handle BLS config files

%package rpm-scriptlets
Summary:        Scripts to create boot entries on kernel updates
Requires:       sdbootutil >= %{version}-%{release}
# make sure to not replace scriptlets with nops on systems that
# use grub2
Conflicts:      grub2
Conflicts:      suse-kernel-rpm-scriptlets
Provides:       suse-kernel-rpm-scriptlets
Obsoletes:      %{name}-filetriggers < %{version}

%description rpm-scriptlets
Scriptlets that call sdbootutil to create boot entries when
kernels are installed or removed

%package kernel-install
Summary:        Hook script for kernel-install
Requires:       /usr/bin/kernel-install
Requires:       sdbootutil >= %{version}-%{release}

%description kernel-install
Plugin script for kernel-install. Note: installation of this
package may disable other plugin scripts that are incompatible.

%prep
%setup -q

%build

%install
install -D -m 755 sdbootutil %{buildroot}%{_bindir}/sdbootutil

mkdir -p %{buildroot}%{_prefix}/lib/module-init-tools/kernel-scriptlets
for a in rpm; do
    install -m 755 "$a-script" %{buildroot}%{_prefix}/lib/module-init-tools/kernel-scriptlets
    for b in post posttrans postun pre preun; do
       ln -s "$a-script" %{buildroot}%{_prefix}/lib/module-init-tools/kernel-scriptlets/$a-$b
    done
done
for a in cert inkmp kmp; do
    for b in post posttrans postun pre preun; do
       ln -s /bin/true %{buildroot}%{_prefix}/lib/module-init-tools/kernel-scriptlets/$a-$b
    done
done

# snapper
install -d -m755 %{buildroot}%{_prefix}/lib/snapper/plugins
for i in 10-sdbootutil.snapper; do
  install -m 755 $i %{buildroot}%{_prefix}/lib/snapper/plugins/$i
done

# kernel-install
install -d -m755 %{buildroot}%{_prefix}/lib/kernel/install.d
for i in 50-sdbootutil.install; do
  install -m 755 $i %{buildroot}%{_prefix}/lib/kernel/install.d/$i
done

# tmpfiles
install -d -m755 %{buildroot}%{_prefix}/lib/tmpfiles.d
for i in kernel-install-sdbootutil.conf; do
  install -m 755 $i %{buildroot}%{_prefix}/lib/tmpfiles.d/$i
done
mkdir -p %{buildroot}/etc/kernel/install.d

%transfiletriggerin -- /usr/lib/systemd/boot/efi /usr/share/efi/%_build_arch
cat > /dev/null || :
[ "$YAST_IS_RUNNING" != 'instsys' ] || exit 0
[ -e /sys/firmware/efi/efivars ] || exit 0
[ -z "$TRANSACTIONAL_UPDATE" ] || exit 0
[ -z "$VERBOSE_FILETRIGGERS" ] || echo "%{name}-%{version}-%{release}: updating bootloader"
sdbootutil update

%posttrans kernel-install
%tmpfiles_create kernel-install-sdbootutil.conf

%files
%license LICENSE
%{_bindir}/sdbootutil

%files rpm-scriptlets
%dir %{_prefix}/lib/module-init-tools
%{_prefix}/lib/module-init-tools/*

%files snapper
%dir %{_prefix}/lib/snapper
%dir %{_prefix}/lib/snapper/plugins
%{_prefix}/lib/snapper/plugins/*

%files kernel-install
%dir %{_prefix}/lib/kernel
%dir %{_prefix}/lib/kernel/install.d
%{_prefix}/lib/kernel/install.d/*
%{_prefix}/lib/tmpfiles.d/kernel-install-sdbootutil.conf
%dir /etc/kernel
%dir /etc/kernel/install.d
%ghost %config(noreplace,missingok) /etc/kernel/install.d/50-depmod.install
%ghost %config(noreplace,missingok) /etc/kernel/install.d/50-dracut.install
%ghost %config(noreplace,missingok) /etc/kernel/install.d/51-dracut-rescue.install
%ghost %config(noreplace,missingok) /etc/kernel/install.d/90-loaderentry.install

%changelog
* Tue Jan 23 2024 lnussel@suse.com
- Update to version 1+git20240122.c0d8f76:
  * Integrate with kernel-install
  * Rework kernel listing a bit
  * Add checks to list-entries
  * List entries for current system only by default
  * Fall back to loader.conf if setting efivar failed
  * Runtime determine kernel image name
  * Add list-snapshots
  * Add list-entries command
* Mon Jan 22 2024 lnussel@suse.com
- Update to version 1+git20240118.7e744b4:
  * Bind mount /etc inside the snapshot
* Thu Dec 21 2023 lnussel@suse.com
- Update to version 1+git20231221.42797ab:
  * Do not fail if LUKS2 section is empty
* Thu Dec 14 2023 lnussel@suse.com
- Update to version 1+git20231214.b186b2d:
  * Fix exit code
  * Revert "Add pcr predictions to initrd for now"
* Wed Dec 13 2023 lnussel@suse.com
- Update to version 1+git20231213.2a07af6:
  * Add update-predictions command
  * Predict all the entries
* Mon Dec 11 2023 lnussel@suse.com
- Update to version 1+git20231211.01c6a76:
  * Add ExclusiveArch for 64-bit EFI architectures
* Wed Nov 29 2023 lnussel@suse.com
- Update to version 1+git20231129.d7f3909:
  * Add pcr predictions to initrd for now
  * Generate new TPM2 predictions with pcr-oracle
  * Update file triggers
  * Fix exit code of update command
  * Add a %%transfiletriggerin to update EFI binaries
  * Update help text
* Tue Nov 14 2023 lnussel@suse.com
- Update to version 1+git20231114.6bcf1d3:
  * Fix quoting when calling dracut
* Thu Nov  2 2023 lnussel@suse.de
- Update to version 1+git20231102.beb4c19:
  * Update sdboot in snapper hook
  * Install command with specific snapshot
  * Install sdbootutil marker next to loader
  * In t-u mode, don't call sdbootutil in rpm scriptlets
* Thu Oct 26 2023 lnussel@suse.com
- Update to version 1+git20231026.f43c33c:
  * Fix generating initrd for random snapshots
* Mon Oct 23 2023 lnussel@suse.de
- Update to version 1+git20231023.873adb9:
  * Use correct image name on aarch64
* Thu Oct 19 2023 Fabian Vogt <fvogt@suse.de>
- Add changes from gh#openSUSE/sdbootutil#21:
  * sdbootutil.spec: Add missing efibootmgr dependency
  * sdbootutil.spec: Make sdbootutil-snapper a hard dependency
* Thu Oct 12 2023 lnussel@suse.de
- Update to version 1+git20231005.890f70c:
  * Add --no-reuse-initrd option
  * Refactor boot descriptive entries
  * feat: more descriptive bootmenu entries
  * Remove stray set -x
  * speed up snapper list
  * Fix misleading comment
  * Fix helptext
* Thu Aug 17 2023 lnussel@suse.de
- Update to version 1+git20230817.2a3cd34:
  * Ignore errors from efibootmgr
  * Update spec file
  * Add marker to flag installation using sdbootutil
  * Refactor and fix boot entry installation
  * Don't exit in warn()
  * feat: use arg_esp_path directly
  * fix: get esp_device from bootctl
  * fix: only install shim for secure boot
  * feat: create only non-existing entries & pass correct ESP partition
  * fix: make efibootmgr silent
  * feat: create boot menu entries when installed
* Mon Aug 14 2023 lnussel@suse.com
- Update to version 1+git20230814.38973c7:
  * Support purge-kernels
  * Fix postun
  * Remove debug logging
* Mon Aug  7 2023 Fabian Vogt <fvogt@suse.com>
- Only install the snapper plugin if sdbootutil is requested
- Bypass git, owner is not available ATM
* Thu Jul 27 2023 lnussel@suse.com
- Update to version 1+git20230727.a0e666f:
  * Set and honor $SYSTEMD_ESP_PATH
  * rpm-script: don't remove kernel on reinstalls
* Wed Jul 26 2023 lnussel@suse.com
- Update to version 1+git20230726.a994d2e:
  * Fix installing extra kernels in MicroOS
  * Replace file triggers with scriptlet
  * Fix cleanup of rollback files
  * Don't install unchanged files
  * Add is-bootable and list-kernels commands
  * Add ARCHITECTURE.md which explains how the setup works
  * Add default loader config when installed
* Mon Jul 17 2023 lnussel@suse.com
- Update to version 1+git20230717.dac075e:
  * Install default boot loader in non-secure-boot case too
* Thu Jul 13 2023 lnussel@suse.de
- Update to version 1+git20230713.df6eaca:
  * Update features
  * Call stty only in interactive mode
  * silence stty errors
* Thu Jul 13 2023 lnussel@suse.de
- Update to version 1+git20230713.356f0c5:
  * Fix rpm dependencies
* Tue Jul 11 2023 lnussel@suse.com
- Update to version 1+git20230711.f5c7e48:
  * Fix setting root and rootflags
* Tue Jul 11 2023 lnussel@suse.com
- Update to version 1+git20230626.1ef6b4d:
  * creating /etc/kernel directory
  * Update help screen
* Thu Jun 15 2023 lnussel@suse.de
- Update to version 1+git20230615.587e134:
  * Handle out of space
* Thu Jun 15 2023 Ludwig Nussel <lnussel@suse.de>
- initial package
